#
# spec file for package nvmetcli
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nvmetcli
Version:        0.7
Release:        lp151.6.3.1
Summary:        Command line interface for the kernel NVMe nvmet
License:        Apache-2.0
Group:          System/Management
Url:            http://git.infradead.org/users/hch/nvmetcli.git
Source:         nvmetcli-v%{version}.tar.gz
Patch1:         %{name}-update-python-to-python3.patch
Patch2:         0001-nvmetcli-don-t-remove-ANA-Group-1-on-clear.patch
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-configshell-fb
Requires:       python3-kmod
Requires(post): systemd
Requires(postun): systemd
Requires(preun): systemd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package contains the command line interface to the NVMe over
Fabrics target in the Linux kernel. It allows configuring the NVMe
target interactively as well as saving / restoring the configuration
to / from a json file.

%prep
%setup -q -n nvmetcli-v%{version}
%patch1 -p1
%patch2 -p1

%build
python3 setup.py build

%install
python3 setup.py install --skip-build --root=%{buildroot} --prefix=usr
mkdir -p %{buildroot}%{_sysconfdir}/nvmet
mkdir -p %{buildroot}%{_prefix}/sbin
install -m 755 nvmetcli %{buildroot}%{_sbindir}/nvmetcli
mkdir -p %{buildroot}%{_prefix}/usr/sbin
ln -s /usr/sbin/service %{buildroot}/usr/sbin/rcnvmet
mkdir -p %{buildroot}%{_unitdir}
install -m 644 nvmet.service %{buildroot}%{_unitdir}/nvmet.service

%post
%service_add_post nvmet.service

%pre
%service_add_pre nvmet.service

%preun
%service_del_preun nvmet.service

%postun
%service_del_postun nvmet.service

%files
%defattr(-,root,root,-)
%{python3_sitelib}
%dir %{_sysconfdir}/nvmet
%{_sbindir}/nvmetcli
/usr/sbin/rcnvmet
%{_unitdir}/nvmet.service
%doc COPYING README

%changelog
* Fri Mar 27 2020 hare@suse.de
- Update to version v0.7:
  * bump version to v0.7
  * nvmetcli: ANA configuration support
  * nvmetcli: simplify the enabled logic
  * nvmetcli: pep8 fixes
  * nvmetcli: support inline_data_size port parameter
  * Revert "nvmetcli: expose nvmet port status and state"
  * Support python3 dictionary access.
  * nvmetcli: expose nvmet port status and state
- Remove patches merged with upstream:
  * nvmetcli-make-dict-access-python-version-independant.patch
  * nvmetcli-ANA-configuration-support.patch
- 'clear' command doesn't handle ANA groups correctly (bsc#1167644)
  adding patch
  - 0001-nvmetcli-don-t-remove-ANA-Group-1-on-clear.patch
* Fri Mar 29 2019 hare@suse.de
- Add ANA support (bsc#1130981)
  * nvmetcli-ANA-configuration-support.patch
* Mon Apr 16 2018 lduncan@suse.com
- Stop using singlespec, since we only need a
  python3 version of this package, and we do not
  want it named "python3-nvmetcli" (bsc#1082208).
  Also, use the "python-six" module to make
  dictionary iteration work for Python 2 and 3,
  adding patch:
  * nvmetcli-make-dict-access-python-version-independant.patch
* Fri Apr 13 2018 lduncan@suse.com
- Support python3 by using the python-six module,
  and convert dictionary access to use 'six' routines,
  so we can work on python 2 or python 3 (bsc#1082208)
* Sun Apr  8 2018 lduncan@suse.com
- Convert to Python3-only siglespec (bsc#1082208)
  * Update the SPEC file, using singlespec format, but
    telling the macros to ignore Python2
  * Tell the scripts to use Python3 instead of python,
    adding patch:
  - nvmetcli-update-python-to-python3.patch
* Tue Jan 23 2018 jthumshirn@suse.com
- Update to version v0.6: (FATE#322737)
  - 0001-nvmetcli-remove-status-method-for-the-uiportnode.patch
  * nvmetcli: remove status method for the UIPortNode
  * nvmetcli: expose ls to dump UI configuration
  * nvmetcli: decorate namespace, subsystem and port UI
  * nvmetcli: port decoration coloring only if its enabled
  * bump version to v0.6
* Fri Dec  1 2017 jthumshirn@suse.com
- Don't display bogus 'disabled' status for ports (bsc#1070533)
  + 0001-nvmetcli-remove-status-method-for-the-uiportnode.patch
* Fri Aug 11 2017 jthumshirn@suse.com
- Update to version v0.5: (FATE#322737)
  - 0001-nvmetcli-add-support-for-NS-UUIDs.patch
  * nvmetcli: add support for NS UUIDs
  * nvmetcli: allow setting of serial number number
  * nvmetcli: allow setting of the subsystem version
  * add a make clean pass to bump-ver.sh
  * bump version to v0.5
* Fri Jun 16 2017 jthumshirn@suse.com
- Add possibiliy to configure Namespace UUIDs (bsc#1038235)
  + 0001-nvmetcli-add-support-for-NS-UUIDs.patch
* Tue May 23 2017 jthumshirn@suse.com
- Change dependency from python-configshell to python-configshell-fb (bsc#1040212)
* Mon May  8 2017 jthumshirn@suse.com
- Update to version v0.4: (bsc#1034105)
  * add example configuration files
  * update .gitignore for the auto-generated manpage formats
  * add a bump-ver.sh script to automate cutting releases
  * bump version to v0.3
  * nvmetcli: fix Port and Host operations in shell
  * nvmetcli: fix Referral operation in shell
  * nvmetcli: Install nvmetcli in /usr/sbin with setup.py
  * nvmetcli: create json file's dir first if it doesn't exist
  * Add fc transport support to nvmetcli
  * bump version to v0.4
* Sat Feb 11 2017 jengelh@inai.de
- expand nvmet
* Wed Oct 12 2016 jthumshirn@suse.com
- Initial import for SUSE (FATE#321732)
